@@ -13,11 +13,11 @@ import java.util.Iterator;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.CellRendererTextEvent;
 import org.gnu.gtk.event.CellRendererToggleEvent;
 import org.gnu.gtk.event.CellRendererToggleListener;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * The CellRendererToggle is a {@link CellRenderer} for boolean data. 
@@ -116,8 +116,8 @@ public class CellRendererToggle extends CellRenderer {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
