@@ -12,10 +12,10 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.CheckMenuItemEvent;
 import org.gnu.gtk.event.CheckMenuItemListener;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * The CheckMenuItem is a menu item that maintains the state of a boolean
@@ -180,8 +180,8 @@ public class CheckMenuItem extends MenuItem {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
