@@ -12,11 +12,11 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TextBufferEvent;
 import org.gnu.gtk.event.TextBufferListener;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * The TextBuffer is the object used to store data to be displayed in a {@link
@@ -92,6 +92,8 @@ public class TextBuffer extends GObject {
 	 * @param text The text to insert
 	 */
 	public void insertText(TextIter iter, String text) {
+	    if (null == text)
+	        text = "";
 		gtk_text_buffer_insert(getHandle(), iter.getHandle(), text);
 	}
 
@@ -100,6 +102,8 @@ public class TextBuffer extends GObject {
 	 * @param text The text to insert
 	 */
 	public void insertText(String text) {
+	    if (null == text)
+	        text = "";
 		gtk_text_buffer_insert_at_cursor(getHandle(), text);
 	}
 
@@ -119,6 +123,8 @@ public class TextBuffer extends GObject {
 	 * @return Whether text was actually inserted
 	 */
 	public boolean insertTextInteractive(TextIter iter, String text, boolean defaultEditable) {
+	    if (null == text)
+	        text = "";
 		return gtk_text_buffer_insert_interactive(getHandle(), iter.getHandle(), text, defaultEditable);
 	}
 
@@ -134,6 +140,8 @@ public class TextBuffer extends GObject {
 	 * @return Whether text was actually inserted.
 	 */
 	public boolean insertTextInteractive(String text, boolean defaultEditable) {
+	    if (null == text)
+	        text = "";
 		return gtk_text_buffer_insert_interactive_at_cursor(getHandle(), text, defaultEditable);
 	}
 
@@ -162,6 +170,10 @@ public class TextBuffer extends GObject {
 	 * @param tag name of TextTag to apply to that text.
 	 */
 	public void insertText( TextIter iter, String text, String tag ){
+	    if (null == text)
+	        text = "";
+	    if (null == tag)
+	        tag = "";
 		insert_with_tag( getHandle(), iter.getHandle(), text, tag );
 	}
 
@@ -173,6 +185,8 @@ public class TextBuffer extends GObject {
 	 * @param tags Array of TextTag names to apply to that text.
 	 */
 	public void insertText( TextIter iter, String text, String[] tags ){
+	    if (null == text)
+	        text = "";
 		TextMark mark = createMark( "jginternal", getEndIter(), true);
 		insertText(iter, text );
 		TextIter start = getIter( mark );
@@ -238,6 +252,8 @@ public class TextBuffer extends GObject {
 	 * @param text The text to use as the content of the buffer.
 	 */
 	public void setText(String text) {
+	    if (null == text)
+	        text = "";
 		gtk_text_buffer_set_text(getHandle(), text);
 	}
 
@@ -352,6 +368,8 @@ public class TextBuffer extends GObject {
 	 * @param where New location for mark
 	 */
 	public void moveMark(String name, TextIter where) {
+	    if (null == name)
+	        name = "";
 		gtk_text_buffer_move_mark_by_name(getHandle(), name, where.getHandle());
 	}
 
@@ -373,6 +391,8 @@ public class TextBuffer extends GObject {
 	 * @param name The name of the mark to delete
 	 */
 	public void deleteMark(String name) {
+	    if (null == name)
+	        name = "";
 		gtk_text_buffer_delete_mark_by_name(getHandle(), name);
 	}
 
@@ -380,6 +400,8 @@ public class TextBuffer extends GObject {
 	 * Returns true if a mark exists with the given name.
 	 */
 	public boolean markExists(String name) {
+	    if (null == name)
+	        name = "";
 		return (gtk_text_buffer_get_mark(getHandle(), name) != 0);
 	}
 
@@ -387,6 +409,8 @@ public class TextBuffer extends GObject {
 	 * Returns the mark named <code>name</code> in the buffer, or <code>null</code> if no such mark exists in the buffer
 	 */
 	public TextMark getMark(String name) {
+	    if (null == name)
+	        name = "";
 		int markHandle = gtk_text_buffer_get_mark(getHandle(), name);
 		if (0 == markHandle)
 			return null;
@@ -472,6 +496,8 @@ public class TextBuffer extends GObject {
 	 * @param end Other bound of range to be tagged
 	 */
 	public void applyTag(String name, TextIter start, TextIter end) {
+	    if (null == name)
+	        name = "";
 		gtk_text_buffer_apply_tag_by_name(getHandle(), name, start.getHandle(), end.getHandle());
 	}
 
@@ -482,6 +508,8 @@ public class TextBuffer extends GObject {
 	 * @param end Other bound of range to be untagged
 	 */
 	public void removeTag(String name, TextIter start, TextIter end) {
+	    if (null == name)
+	        name = "";
 		gtk_text_buffer_remove_tag_by_name(getHandle(), name, start.getHandle(), end.getHandle());
 	}
 
@@ -489,7 +517,7 @@ public class TextBuffer extends GObject {
 	 * Removes all tags in the range between start and end. Be careful with this
 	 * function; it could remove tags added in code unrelated to the code you're
 	 * currently writing. That is, using this function is probably a bad idea if
-	 * you have two or more unrelated code sections that add tags.
+v	 * you have two or more unrelated code sections that add tags.
 	 * @param start One bound of range to be untagged
 	 * @param end Other bound of range to be untagged
 	 */
@@ -743,8 +771,8 @@ public class TextBuffer extends GObject {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
