@@ -9,14 +9,32 @@
 
 #include <jni.h>
 #include <string.h>
+#include <sys/types.h>
 #include <glib.h>
 #include <glib-object.h>
-#include "jg_jnu.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
+static jfieldID gtkobj_fieldID = NULL;
+
+#define JGTKO(x) jobject_to_gtk(env, x)
+
+/* Given a Java object, this method gets the native GtkObject object */
+GObject *
+jobject_to_gtk(JNIEnv *env, jobject obj)
+{
+  jint obj_pointer;
+
+//  if(!gtkobj_fieldID)
+    gtkobj_fieldID = (*env)->GetFieldID(env, (*env)->GetObjectClass(env, obj), 
+					"handle", "I");
+  obj_pointer = (*env)->GetIntField(env, obj, gtkobj_fieldID);
+  
+  return G_OBJECT((void *)obj_pointer);
+}
+
 typedef struct {
   JNIEnv *env;
   jobject obj;  /* object to recieve the signal */
@@ -37,6 +55,53 @@ typedef struct {
   CallbackData *cbdata;
 } JGClosure;
 
+
+static char *
+javatype_from_gtktype(GType argtype)
+{
+  char *javatype = g_malloc(50);
+  const char *tmp;
+
+  tmp = g_type_name(argtype);
+    
+  if (strncmp(tmp, "Gtk", 3) == 0) {
+    if (strlen(tmp) > 3)
+      tmp = &tmp[3];
+    sprintf(javatype, "org/gnu/gtk/%s", tmp);
+  }
+  else if (strncmp(tmp, "Gdk", 3) == 0) {
+    if (strlen(tmp) > 3)
+      tmp = &tmp[3];
+    sprintf(javatype, "org/gnu/gdk/%s", tmp);
+  }
+  else if (strncmp(tmp, "Gno", 3) == 0) {
+    if (strlen(tmp) > 5)
+      tmp = &tmp[5];
+    sprintf(javatype, "org/gnu/gnome/%s", tmp);
+  }
+  else if (strncmp(tmp, "Pan", 3) == 0) {
+    if (strlen(tmp) > 5)
+      tmp = &tmp[5];
+    sprintf(javatype, "org/gnu/pango/%s", tmp);
+  }
+  else if (strncmp(tmp, "Atk", 3) == 0) {
+    if (strlen(tmp) > 3)
+      tmp = &tmp[3];
+    sprintf(javatype, "org/gnu/atk/%s", tmp);
+  }
+  else if (strncmp(tmp, "Html", 4) == 0) {
+    sprintf(javatype, "org/gnu/gtkhtml/%s", tmp);
+  }
+  else if (strncmp(tmp, "Dom", 3) == 0) {
+    sprintf(javatype, "org/gnu/gtkhtml/dom/%s", tmp);
+  }
+  else
+    sprintf(javatype, "%s", tmp);
+
+  return javatype;
+}
+
+
 /* This method actually recieves all callbacks in the system.  It 
  * recieves a CallbackData struct as its' data.  It then determines
  * what Java method to call and invokes it passing the correct parameters */
@@ -53,14 +118,11 @@ jg_signal_cb(GClosure *closure,
   CallbackData *cbdata;
   int i;
   jmethodID mid;
-  jclass clazz;
   jobject localObj;
-  jobject peer;
-  jfieldID peerfid;
+  jint peer;
   jthrowable exc;
   gboolean b;
   const gchar* str;
-  const gchar* jtype;
   int jargsLen = n_param_values;  
   
 
@@ -119,16 +181,16 @@ jg_signal_cb(GClosure *closure,
       jargs[i-1].l = localObj;
       break;
     case G_TYPE_BOXED:
-      peer = getHandleFromPointer(cbdata->env, g_value_get_boxed(&param_values[i]));
-      jargs[i-1].l = peer;
+      peer = (jint)g_value_get_boxed(&param_values[i]);
+      jargs[i-1].i = peer;
       break;
     case G_TYPE_POINTER:
-      peer = getHandleFromPointer(cbdata->env, g_value_get_pointer(&param_values[i]));
-      jargs[i-1].l = peer;
+      peer = (jint)g_value_get_pointer(&param_values[i]);
+      jargs[i-1].i = peer;
       break;
     default:
-      peer = getHandleFromPointer(cbdata->env, g_value_get_object(&param_values[i]));
-      jargs[i-1].l = peer;
+      peer = (jint)g_value_get_object(&param_values[i]);
+      jargs[i-1].i = peer;
       break;
     }
   }
@@ -253,16 +315,17 @@ jg_arg_signature(GString *str, GType argtype)
     as = "java/lang/String";
     break;
   case G_TYPE_BOXED:
-    as = "org/gnu/glib/Handle";
+    ac = 'I';
     break;
   case G_TYPE_POINTER:
-    as = "org/gnu/glib/Handle";
+    ac = 'I';
     break;
   case G_TYPE_OBJECT:
-    as = "org/gnu/glib/Handle";
+    as = javatype_from_gtktype( argtype );
+    free_as = TRUE;
     break;
   default:
-    as = "org/gnu/glib/Handle";
+    ac = 'I';
     break;
   case G_TYPE_INVALID:
     g_error("Type %d - should not be reached", (gint)argtype);
@@ -331,8 +394,7 @@ jg_cbdata_new(JNIEnv *env,
   jthrowable exc;
   jclass Exception;
   
-  //  gtko = (GObject*)getPointerFromHandle(env, obj);
-  gtko = (GObject*)getPointerFromJavaGObject(env, obj);
+  gtko = JGTKO(obj);
   sigid = g_signal_lookup(signame, G_OBJECT_TYPE(gtko));
   g_assert(sigid > 0);
   g_signal_query(sigid, &siginfo);
@@ -360,8 +422,8 @@ jg_cbdata_new(JNIEnv *env,
 			sigfunc, sigsig);
   exc = (*env)->ExceptionOccurred(env);
   if (exc) {
-    g_warning("Java-GNOME - cannot find callback method %s in the specified object with signature %s\n",
-	   sigfunc, sigsig);
+    g_warning("Java-GNOME - cannot find callback method %s in the specified object with signature %s\n", 
+	      sigfunc, sigsig);
     (*env)->ExceptionClear(env);
 	Exception = (* env)->FindClass(env, "java/lang/RuntimeException");
     (* env)->ThrowNew(env, Exception, "" );
@@ -397,7 +459,7 @@ jg_static_cbdata_new(JNIEnv *env,
   jthrowable exc;
   jclass Exception;
   
-  gtko = (GObject*)getPointerFromJavaGObject(env, obj);
+  gtko = JGTKO(obj);
   sigid = g_signal_lookup(signame, G_OBJECT_TYPE(gtko));
   g_assert(sigid > 0);
   g_signal_query(sigid, &siginfo);
@@ -458,12 +520,10 @@ static jint create_callback(JNIEnv *env,
 
   jclass Exception;
 
-//  go = (GObject*)getPointerFromHandle(env, obj);
-  go = (GObject*)getPointerFromJavaGObject(env, obj);
+  go = JGTKO(obj);
   signame = (*env)->GetStringUTFChars(env, sigstring, NULL);
   sigfunc = (*env)->GetStringUTFChars(env, func, NULL);
   
-
   if (!g_signal_parse_name(signame, G_OBJECT_TYPE(go),
 			   &sigid, &detail, TRUE)) {
     g_critical("Java-GNOME - unknown signal name %s, function %s, object %s.\n", signame, sigfunc, G_OBJECT_TYPE_NAME(go));
@@ -471,6 +531,7 @@ static jint create_callback(JNIEnv *env,
     (* env)->ThrowNew(env, Exception, "" );
     return 0;
   }
+
   cbdata = jg_cbdata_new(env, obj, cbrecv, data, signame, sigfunc);
 
   if (cbdata == NULL)
@@ -479,8 +540,7 @@ static jint create_callback(JNIEnv *env,
   closure = jg_closure_new();
   ((JGClosure *)closure)->cbdata = cbdata;
 
-  //retval = g_signal_connect_closure_by_id(getPointerFromHandle(env, obj),
-  retval = g_signal_connect_closure_by_id(getPointerFromJavaGObject(env, obj),
+  retval = g_signal_connect_closure_by_id(JGTKO(obj),
 					  sigid,
 					  detail,
 					  closure,
@@ -488,6 +548,7 @@ static jint create_callback(JNIEnv *env,
 
   (*env)->ReleaseStringUTFChars(env, sigstring, signame);
   (*env)->ReleaseStringUTFChars(env, func, sigfunc);
+    
   return retval;
 }
 
@@ -509,7 +570,7 @@ static jint create_static_callback(JNIEnv *env,
   GClosure *closure;
   jclass Exception;
   
-  go = (GObject*)getPointerFromJavaGObject(env, obj);
+  go = JGTKO(obj);
   signame = (*env)->GetStringUTFChars(env, sigstring, NULL);
   sigfunc = (*env)->GetStringUTFChars(env, func, NULL);
   
@@ -528,7 +589,7 @@ static jint create_static_callback(JNIEnv *env,
     
   closure = jg_closure_new();
   ((JGClosure *)closure)->cbdata = cbdata;
-  retval = g_signal_connect_closure_by_id(getPointerFromJavaGObject(env, obj),
+  retval = g_signal_connect_closure_by_id(JGTKO(obj),
 					  sigid,
 					  detail,
 					  closure,
@@ -562,7 +623,7 @@ JNIEXPORT jint JNICALL
 Java_org_gnu_glib_GObject_addEventHandler__Ljava_lang_String_2Ljava_lang_String_2Ljava_lang_Object_2 
 (JNIEnv *env, jobject obj, jstring sigstring, jstring func, jobject cbrecv)
 { 
-	return create_callback(env, obj, sigstring, func, cbrecv, NULL);
+  return create_callback(env, obj, sigstring, func, cbrecv, NULL);
 }
 
 
@@ -626,7 +687,7 @@ Java_org_gnu_glib_GObject_addEventHandler__Ljava_lang_String_2Ljava_lang_String_
 JNIEXPORT void JNICALL
 Java_org_gnu_glib_GObject_removeEventHandler(JNIEnv *env, jobject obj, jint sigid)
 {
-  g_signal_handler_disconnect(getPointerFromHandle(env, obj), sigid);
+  g_signal_handler_disconnect(JGTKO(obj), sigid);
 }
 
 
@@ -636,58 +697,61 @@ Java_org_gnu_glib_GObject_removeEventHandler(JNIEnv *env, jobject obj, jint sigi
  * Signature: (ILjava/lang/String;)Ljava/lang/Object;
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_getData
-  (JNIEnv *env, jobject obj, jobject handle, jstring key)
+  (JNIEnv *env, jobject obj, jint handle, jstring key)
 {
-    gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
-    GObject *handle_g = (GObject *)getPointerFromHandle(env, handle);
-    JGRef *ref = (JGRef*) g_object_get_data(handle_g, k);
-    (*env)->ReleaseStringUTFChars(env, key, k);
-    if (ref == NULL) {
-        return NULL;
-    } else {
-        return ref->object;
-    }
+	gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
+	JGRef *ref = (JGRef*) g_object_get_data((GObject*)handle, k);
+	(*env)->ReleaseStringUTFChars(env, key, k);
+	if (ref == NULL){
+		return NULL;
+	}else{
+		return ref->object;
+	}
 }
 
-static void jg_gobject_destroy(gpointer data)
+
+static void
+jg_gobject_destroy(gpointer data)
 {
 	JGRef *ref = (JGRef*) data;
 	(* ref->env)->DeleteGlobalRef( ref->env, ref->object);
 	g_free( ref );
 }
-
 /*
  * Class:     org_gnu_glib_GObject
  * Method:    setData
  * Signature: (ILjava/lang/String;Ljava/lang/Object;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_setData
-(JNIEnv *env, jclass cls, jobject handle, jstring key, jobject data)
+  (JNIEnv *env, jobject obj, jint handle, jstring key, jobject data)
 {
-    GObject *handle_g = (GObject *)getPointerFromHandle(env, handle);
-    gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
-
-    JGRef *ref = g_new( JGRef, 1 );
-    ref->env = env;
-    ref->object = (* env)->NewGlobalRef(env, data);
-
-    g_object_set_data_full(handle_g, k, ref, jg_gobject_destroy ) ;
-    (*env)->ReleaseStringUTFChars(env, key, k);
+	gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
+	JGRef *ref = g_new( JGRef, 1 );
+	ref->env = env;
+	ref->object = (* env)->NewGlobalRef(env, data);
+	g_object_set_data_full((GObject*)handle, 
+				k, 
+				ref,
+				jg_gobject_destroy
+				) ;
+	(*env)->ReleaseStringUTFChars(env, key, k);
 }
 
 void logFunc(const gchar* logDomain, GLogLevelFlags logLevel, const gchar* message, gpointer userData)
 {
-    jclass gobject;
-    jmethodID stackHandler;
-    JNIEnv *env = (JNIEnv*)userData;
-    jstring msg;
+	jclass gobject;
+	jmethodID stackHandler;
+	JNIEnv *env = (JNIEnv*)userData;
+	jstring msg;
+	jvalue *jargs;
 	
-    (*env)->ExceptionClear(env);
-    msg = (*env)->NewStringUTF(env, message);
+	msg = (*env)->NewStringUTF(env, message);
+	jargs = alloca(sizeof(jvalue));
+    jargs[0].l = msg;
 	
-    gobject = (*env)->FindClass(env, "org/gnu/glib/GObject");
-    stackHandler = (*env)->GetStaticMethodID(env, gobject, "printStackTrace", "(Ljava/lang/String;)V");
-    (*env)->CallStaticVoidMethod(env, gobject, stackHandler, msg);
+	gobject = (*env)->FindClass(env, "Lorg/gnu/glib/GObject;");
+	stackHandler = (*env)->GetMethodID(env, gobject, "printStackTrace", "(Ljava/lang/String;)V");
+    (*env)->CallStaticVoidMethodA(env, gobject, stackHandler, jargs);
 	
 }
 
@@ -695,9 +759,8 @@ void logFunc(const gchar* logDomain, GLogLevelFlags logLevel, const gchar* messa
  * Class:     org_gnu_glib_GObject
  * Method:    registerLogHandler
  * Signature: ()V
- */ 
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_registerLogHandler
-(JNIEnv *env, jclass cls)
+ */ JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_registerLogHandler
+  (JNIEnv *env, jclass cls)
 {
 	g_log_set_handler(NULL, G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL |
 			G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION, logFunc, (gpointer)env);
@@ -713,253 +776,6 @@ JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_registerLogHandler
                      | G_LOG_FLAG_RECURSION, logFunc, (gpointer) env);
 }
 
-/*
- * Class:     org_gnu_glib_GObject
- * Method:    getNullHandle
- * Signature: ()Lorg/gnu/glib/Handle;
- */
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_getNullHandle
-(JNIEnv *env, jclass cls)
-{
-    return getHandleFromPointer(env, NULL);
-}
-
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_g_1object_1new
-(JNIEnv *env, jclass cls, jint object_type)
-{
-    GType object_type_g = (GType)object_type;
-    return getHandleFromPointer(env, g_object_new(object_type_g, NULL, NULL));
-}
-
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_g_1object_1class_1find_1property
-(JNIEnv *env, jclass cls, jobject oclass, jstring property_name)
-{
-    GObjectClass * oclass_g = 
-        G_OBJECT_GET_CLASS((GObject *)getPointerFromHandle(env, oclass));
-    const gchar * property_name_g = 
-        (const gchar *)(*env)->GetStringUTFChars(env, property_name, 0);
-
-    jobject ret_g = getHandleFromPointer(env, g_object_class_find_property(oclass_g, property_name_g));
-
-    (*env)->ReleaseStringUTFChars(env, property_name, property_name_g);
-    return ret_g;
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_g_1object_1set_1property
-(JNIEnv *env, jclass cls, jobject object, jstring property_name, jobject value)
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    const gchar * property_name_g = (const gchar *)(*env)->GetStringUTFChars(env, property_name, 0);
-    const GValue * value_g = (const GValue *)getPointerFromHandle(env, value);
-    g_object_set_property(object_g, property_name_g, value_g);
-    (*env)->ReleaseStringUTFChars(env, property_name, property_name_g);
-}
-
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_g_1object_1get_1property
-(JNIEnv *env, jclass cls, jobject object, jstring property_name)
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    const gchar * property_name_g = 
-        (const gchar *)(*env)->GetStringUTFChars(env, property_name, 0);
-
-    // Initialize the GValue.
-    GParamSpec *pspec = 
-        g_object_class_find_property(G_OBJECT_GET_CLASS(object_g), 
-                                     property_name_g);
-    if ( !pspec ) {
-        return NULL;
-    }
-    GValue * value_g = g_malloc( sizeof( GValue ) );
-    value_g->g_type = 0;
-    value_g = g_value_init(value_g, pspec->value_type);
-
-    // Get the property.
-    g_object_get_property(object_g, property_name_g, value_g);
-    (*env)->ReleaseStringUTFChars(env, property_name, property_name_g);
-    return getHandleFromPointer(env, value_g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_g_1object_1freeze_1notify
-(JNIEnv *env, jclass cls, jobject object)
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    g_object_freeze_notify(object_g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_g_1object_1notify
-(JNIEnv *env, jclass cls, jobject object, jstring property_name)
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    const gchar * property_name_g = (const gchar *)(*env)->GetStringUTFChars(env, property_name, 0);
-    g_object_notify(object_g, property_name_g);
-    (*env)->ReleaseStringUTFChars(env, property_name, property_name_g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_g_1object_1thaw_1notify
-(JNIEnv *env, jclass cls, jobject object)
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    g_object_thaw_notify(object_g);
-}
-
-static JGFuncCallbackRef *propertyNotifRef = NULL;
-
-static void propertyNotificationCB(GObject *gobject, GParamSpec *arg1,
-                                   gpointer data)
-{
-    JGFuncCallbackRef *ref = (JGFuncCallbackRef*) data;
-    (* ref->env)->CallVoidMethod(ref->env, 
-                                 ref->obj, 
-                                 ref->methodID,
-                                 getHandleFromPointer(ref->env, gobject),
-                                 (*ref->env)->NewStringUTF(ref->env, 
-                                                           arg1->name));
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_connectNotifySignal
-(JNIEnv *env, jclass cls, jobject objhandle, jobject object, jstring callback)
-{
-    propertyNotifRef = g_new( JGFuncCallbackRef, 1 );
-    propertyNotifRef->env = env;
-    propertyNotifRef->obj = (* env)->NewGlobalRef(env, object);
-
-    const char *funcname = (*env)->GetStringUTFChars(env, callback, NULL);
-    const char *sig = "(Lorg/gnu/glib/Handle;Ljava/lang/String;)V";
-    // Get method id for the callback method name.
-    propertyNotifRef->methodID = 
-        (*env)->GetMethodID(env, 
-                            (*env)->GetObjectClass(env, propertyNotifRef->obj),
-                            funcname, sig );
-    if ( propertyNotifRef->methodID == NULL ) {
-        g_warning( "Can't find %s%s.\n", funcname, sig );
-        (*env)->ReleaseStringUTFChars(env, callback, funcname);
-        g_free( propertyNotifRef );
-        propertyNotifRef = NULL;
-        return;
-    }
-    (*env)->ReleaseStringUTFChars(env, callback, funcname);
-
-    GObject * object_g = (GObject *)getPointerFromHandle(env, objhandle);
-    g_object_connect(object_g, "signal::notify", 
-                     propertyNotificationCB, propertyNotifRef, NULL);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_disconnectNotifySignal
-(JNIEnv *env, jclass cls, jobject object)
-{
-    if ( propertyNotifRef ) {
-        GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-        g_object_disconnect(object_g, "any_signal::notify",
-                            propertyNotificationCB, propertyNotifRef, NULL);
-        g_free( propertyNotifRef );
-    }
-}
-
-JNIEXPORT jint JNICALL Java_org_gnu_glib_GObject_getGTypeOfProperty(JNIEnv* env, jclass cls, jobject object, jstring prop) 
-{
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    const gchar * prop_g = 
-        (const gchar *)(*env)->GetStringUTFChars(env, prop, 0);
-
-    GParamSpec *pspec = 
-        g_object_class_find_property(G_OBJECT_GET_CLASS(object_g), prop_g);
-    if ( !pspec ) {
-        return -1;
-    }
-
-    return pspec->value_type;
-}
-
-JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_instantiateJGObjectFromGType(JNIEnv* env, jclass cls, int type, jobject handle) 
-{
-    jthrowable exc;
-    const gchar* jtype = javatype_from_gtktype((GType)type);
-    jclass clazz = (* env)->FindClass(env, jtype);
-    exc = (*env)->ExceptionOccurred(env);
-    if (exc) {
-        g_warning( "Can't find class: %s\n", jtype );
-    	(*env)->ExceptionDescribe(env);
-    	(*env)->ExceptionClear(env);
-        return NULL;
-    }
-    
-    if (clazz == NULL) {
-        clazz = (* env)->FindClass(env, "org/gnu/glib/GObject");
-        if (clazz == NULL) {
-            // Should never happen!
-            return NULL;
-        }
-    }
-    g_free((gpointer)jtype);
-    
-    jobject localObj = (* env)->AllocObject(env, clazz);
-    jmethodID handlemid = 
-        (* env)->GetMethodID(env, clazz, 
-                             "setHandle", "(Lorg/gnu/glib/Handle;)V");
-    exc = (*env)->ExceptionOccurred(env);
-    if (exc) {
-        g_warning( "No such method: setHandle(Lorg/gnu/glib/Handle;)V\n" );
-    	(*env)->ExceptionDescribe(env);
-    	(*env)->ExceptionClear(env);
-        return NULL;
-    }
-
-    (* env)->CallVoidMethod(env, localObj, handlemid, handle);
-    return localObj;
-}
-
-JNIEXPORT jint JNICALL Java_org_gnu_glib_GObject_getIntFromHandle(JNIEnv* env, jclass cls, jobject handle) 
-{
-    void *handle_g = getPointerFromHandle(env, handle);
-    return (jint) *(gint*)handle;
-}
-
-/*
- * My test property setting method.  :-)
- */
-JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_setTestProperty(JNIEnv* env, jclass cls, jobject object, jstring prop, jobject val) 
-{
-    printf( "C-setTestProperty - start\n" );
-    GObject * object_g = (GObject *)getPointerFromHandle(env, object);
-    const gchar * prop_g = 
-        (const gchar *)(*env)->GetStringUTFChars(env, prop, 0);
-    gpointer val_g = (gpointer)getPointerFromHandle(env, val);
-    printf( "C-setTestProperty - obj_g=%d,prop_g=%s,val_g=%d\n", object_g, prop_g, val_g );
-
-    printf( "C-setTestProperty - g_object_class_find_property(obj_g,prop_g)\n" );
-    GParamSpec *pspec = 
-        g_object_class_find_property(G_OBJECT_GET_CLASS(object_g), prop_g);
-    if ( !pspec ) {
-        return;
-    }
-    printf( "C-setTestProperty - got pspec\n" );
-
-    printf( "C-setTestProperty - gval = g_malloc GValue\n" );
-    GValue *gval = (GValue *) g_malloc(sizeof(GValue));
-    gval->g_type = 0;
-    printf( "C-setTestProperty - g_value_init( gval=%d, pspec->value_type=%d )\n", gval, pspec->value_type );
-    gval = g_value_init( gval, pspec->value_type );
-    printf( "C-setTestProperty - inited\n" );
-
-    printf( "C-setTestProperty - g_value_set_ for gval=%d\n", gval );
-    if ( G_VALUE_HOLDS_BOXED( gval ) ) {
-        printf( "C-setTestProperty - HOLDS_BOXED.\n" );
-        g_value_set_boxed( gval, val_g );
-    } else if ( G_VALUE_HOLDS_OBJECT( gval ) ) {
-        printf( "C-setTestProperty - HOLDS_OBJECT.\n" );
-        g_value_set_object( gval, val_g );
-    } else if ( G_VALUE_HOLDS_POINTER( gval ) ) {
-        printf( "C-setTestProperty - HOLDS_POINTER.\n" );
-        g_value_set_pointer( gval, val_g );
-    } else {
-        printf( "C-setTestProperty - not anything!.\n" );
-        return;
-    }
-    printf( "C-setTestProperty - g_value_set completed.\n" );
-    printf( "C-setTestProperty - g_object_set_property(obj_g=%d, prop_g=%s, gval=%d).\n", object_g, prop_g, gval );
-    g_object_set_property(object_g, prop_g, gval );
-    printf( "C-setTestProperty - end\n" );
-}
 
 #ifdef __cplusplus
 }
